/**
 * Vrátí kořenovou URL serveru na základě aktuálního prostředí (vývojovou či produkční).
 * 
 * @returns kořenová URL serveru
 */
export const getBaseUrl = (): string => {
    if (process.env.PUBLIC_URL) {
        return process.env.PUBLIC_URL;
    }
    return 'http://127.0.0.1:3001';
}

const TOKEN_KEY = "token";

/**
 * Uloží token do local storage prohlížeče.
 * 
 * @param token token
 */
export const storeToken = (token: string) => {
    localStorage.setItem(TOKEN_KEY, token);
}

/**
 * Vrátí token z local storage, pokud tam je.
 * 
 * @returns token nebo null
 */
export const getToken = (): string | null => {
    return localStorage.getItem(TOKEN_KEY);
}

/**
 * Odstraní token z local storage, pokud tam je.
 */
export const deleteToken = () => {
    localStorage.removeItem(TOKEN_KEY);
}

/**
 * Vrátí human-readable reprezentaci předaného data a času pro zobrazení.
 */
export function getHumanDateTime(datetime: Date) {
    let currentDay = String(datetime.getDate()).padStart(2, '0');
    let currentMonth = String(datetime.getMonth() + 1).padStart(2, "0");
    let currentYear = datetime.getFullYear();
    let currentHours = String(datetime.getHours()).padStart(2, '0');
    let currentMinutes = String(datetime.getMinutes()).padStart(2, "0");
    return `${currentDay}.${currentMonth}.${currentYear} ${currentHours}:${currentMinutes}`;
}
